Crate use_oci_runtime

Crate use_oci_runtime 

use-oci-runtime

use-oci-runtime provides OCI runtime spec primitives for process, mount, namespace, hook, capability, resource, and rootfs metadata.

It is part of the use-oci RustUse workspace for small, focused OCI primitive crates. It does not perform network calls, shell out to runtimes, implement a registry client, or build container images.

License

Licensed under either of the following, at your option:

  • Apache License, Version 2.0
  • MIT license

Structs

Capability
Cwd
Mount
OCI mount metadata. This type does not mount filesystems.
ProcessArg
ResourceLimit
Resource limit metadata.
RootFilesystem
RuntimeEnv
RuntimeSpec
OCI runtime metadata. This type does not execute a runtime.

Enums

MountKind
OCI mount kind metadata.
RuntimeError
Errors returned when runtime metadata is invalid.